package com.qmth.ops.api.controller.admin;

import com.qmth.ops.api.constants.OpsApiConstants;
import com.qmth.ops.api.security.AdminSession;
import com.qmth.ops.api.security.Permission;
import com.qmth.ops.api.vo.OcrSupplierVO;
import com.qmth.ops.biz.domain.OcrSupplier;
import com.qmth.ops.biz.service.OcrClientService;
import com.qmth.ops.biz.service.OcrSupplierService;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;
import java.util.stream.Collectors;

@RestController
@RequestMapping(OpsApiConstants.ADMIN_URI_PREFIX + "/ocr/supplier")
public class OcrSupplierController {

    @Resource
    private OcrSupplierService ocrSupplierService;

    @Resource
    private OcrClientService ocrClientService;

    @PostMapping("/list")
    public List<OcrSupplierVO> list() {
        return ocrSupplierService.list().stream().map(OcrSupplierVO::new).collect(Collectors.toList());
    }

    @PostMapping("/detail")
    public OcrSupplier detail(@RequestParam Long id) {
        return ocrSupplierService.getById(id);
    }

    @PostMapping("/insert")
    public OcrSupplier insert(@RequestAttribute AdminSession adminSession, OcrSupplier supplier) {
        adminSession.hasPermission(Permission.OCR_SUPPLIER_INSERT);
        return ocrSupplierService.insert(supplier);
    }

    @PostMapping("/update")
    public OcrSupplier update(@RequestAttribute AdminSession adminSession, OcrSupplier supplier) {
        adminSession.hasPermission(Permission.OCR_SUPPLIER_EDIT);
        ocrSupplierService.update(supplier);
        ocrClientService.init();
        return ocrSupplierService.getById(supplier.getId());
    }

}
