package com.qmth.ops.biz.service;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.qmth.ops.biz.dao.VersionDao;
import com.qmth.ops.biz.domain.App;
import com.qmth.ops.biz.domain.Version;
import com.qmth.ops.biz.query.VersionQuery;
import com.qmth.ops.biz.utils.VersionNumber;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import javax.validation.constraints.NotNull;

@Service
public class VersionService extends ServiceImpl<VersionDao, Version> {

    @Resource
    private VersionDao versionDao;

    @Transactional
    public Version insert(@NotNull App app, @NotNull VersionNumber versionNumber) {
        Version version = new Version();
        version.setAppId(app.getId());
        version.setArchived(false);
        version.setMainNumber(versionNumber.getMain());
        version.setMiddleNumber(versionNumber.getMiddle());
        version.setSubNumber(versionNumber.getSub());
        version.setName(versionNumber.toString());
        version.setCreateTime(System.currentTimeMillis());
        version.setUpdateTime(version.getCreateTime());
        versionDao.insert(version);
        return version;
    }

    @Transactional
    public Version update(@NotNull Version version) {
        versionDao.update(version, new LambdaUpdateWrapper<Version>()
                .set(version.getArchived() != null, Version::getArchived, version.getArchived())
                .set(Version::getUpdateTime, System.currentTimeMillis()).eq(Version::getId, version.getId()));
        return versionDao.selectById(version.getId());
    }

    public IPage<Version> query(@NotNull VersionQuery query) {
        return versionDao.selectPage(query, query.build());
    }

    public Version findByAppAndNumber(@NotNull Long appId, @NotNull VersionNumber number) {
        return versionDao.selectOne(new LambdaQueryWrapper<Version>().eq(Version::getAppId, appId)
                .eq(Version::getMainNumber, number.getMain()).eq(Version::getMiddleNumber, number.getMiddle())
                .eq(Version::getSubNumber, number.getSub()));
    }

    public Version findLatestByApp(@NotNull Long appId) {
        return versionDao.selectOne(new LambdaQueryWrapper<Version>().eq(Version::getAppId, appId)
                .orderByDesc(Version::getMainNumber, Version::getMiddleNumber, Version::getSubNumber).last("limit 1"));
    }
}

